# TGSDL

![Colorclip](https://gist.githubusercontent.com/acidfreakz/104ccc13eeb63f212170ec92aad1d4e3/raw/9fa794dc5ee6826fff0d597ab16f6f096c6d47af/TGSDL.svg)

Telegram sticker pack downloader
- Fast and Simple 

[![Telegram](https://img.shields.io/badge/Telegram-2CA5E0?style=flat&logo=telegram&logoColor=white)](https://t.me/onefinalhug) 

![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)

## How to install
```
pip install tgsdl
```
## Example use
```
from tgsdl import download_sticker_pack

pack_url = "https://t.me/addstickers/SophiaLillis_lillislove"
download_sticker_pack(pack_url)
````
```
>>> tgsdl https://t.me/addstickers/SophiaLillis_lillislove
```

